Module comet::allocator::overflow[][src]

Structs

The OverflowAllocator is used to allocate medium sized objects (objects of at least MEDIUM_OBJECT bytes size) within the immix space to limit fragmentation in the NormalAllocator.