Struct comet::allocator::overflow::OverflowAllocator[][src]

pub struct OverflowAllocator { /* fields omitted */ }
The OverflowAllocator is used to allocate medium sized objects (objects of at least MEDIUM_OBJECT bytes size) within the immix space to limit fragmentation in the NormalAllocator.

Implementations

Create a new OverflowAllocator backed by the given BlockAllocator.