Module comet::c_api[][src]

Functions

Add GC constraint to the Comet Heap. Each constraint is executed when marking starts to obtain list of root objects.

Add core constraints to the heap. This one will setup stack scanning routines.

Allocates memory and returns pointer. NULL is returned if no memory is available.

Allocates memory and returns pointer. When no memory is left process is aborted.

Free comet heap

Upgrade weak ref. If it is still alive then pointer is returned otherwise NULL is returned.