Struct comet::gcref::GcRef [−][src]
#[repr(C)]pub struct GcRef<T> { /* fields omitted */ }Expand description
A typed garbage collected pointer to a value.
This is the equivalent of a garbage collected smart-pointer.
The smart pointer is simply a guarantee to the garbage collector that this points to a garbage collected object with the correct header, and not some arbitrary bits that you’ve decided to heap allocate.
Implementations