Struct comet::gcref::WeakSlot [−][src]
pub struct WeakSlot { /* fields omitted */ }Trait Implementations
If true finalizer is executed at the end of GC cycle for this type.
In most cases compiler should be smart enough to determine if NON_TRIVIAL_DTOR is true
but in some rare unsafe cases you might set it to false by yourself. Read more
Finalization callback executed by GC at the end of GC cycle. It defaults to FinalizeTrait::finalize.
Function invoking the tracing for an object of type T. Read more
trace_ method is used for C FFI safety.
Returns trace descriptor for type that implements this trait. Not recommended to override it.