Struct comet::header::EncodedHigh[][src]

pub struct EncodedHigh { /* fields omitted */ }

Implementations

Returns an instance with zero initialized data.

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

Converts the given bytes directly into the bitfield struct.