Struct comet::heap::DeferPoint [−][src]
pub struct DeferPoint { /* fields omitted */ }Expand description
Defer point. GC cycle is deferred when instance of this struct is alive.
pub struct DeferPoint { /* fields omitted */ }Defer point. GC cycle is deferred when instance of this struct is alive.