Struct comet::internal::card_table::CardTable[][src]

pub struct CardTable { /* fields omitted */ }
Maintain a card table from the the write barrier. All writes of non-null values to heap addresses should go through an entry in WriteBarrier, and from there to here.

Implementations

Returns a value that when added to a heap address >> CARD_SHIFT will address the appropriate card table byte. For convenience this value is cached in every local heap.