Struct comet::internal::space_bitmap::SpaceBitmap[][src]

pub struct SpaceBitmap<const ALIGN: usize> { /* fields omitted */ }

Implementations

Visit marked bits in bitmap.

NOTE: You can safely change bits in this bitmap during visiting it since it loads word and then visits marked bits in it.