Struct comet::visitor::Visitor[][src]

#[repr(C)]
pub struct Visitor { /* fields omitted */ }

Implementations

Trace method for raw pointers. Prefer the versions for managed pointers.

Trace method for inlined objects that are not allocated themselves but otherwise follow managed heap layout and have a trace() method.

Traces typed gc reference.

Traces untyped gc reference.