pub struct EncodedHigh { /* fields omitted */ }
Returns an instance with zero initialized data.
Returns the underlying bits.
The returned byte array is layed out in the same way as described
here.
Converts the given bytes directly into the bitfield struct.
Performs copy-assignment from source. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.