Struct comet::internal::space_bitmap::SpaceBitmap [−][src]
pub struct SpaceBitmap<const ALIGN: usize> { /* fields omitted */ }Implementations
pub fn visit_marked_range(
&self,
visit_begin: *const u8,
visit_end: *const u8,
visitor: impl FnMut(*mut HeapObjectHeader)
)
pub fn visit_marked_range(
&self,
visit_begin: *const u8,
visit_end: *const u8,
visitor: impl FnMut(*mut HeapObjectHeader)
)
Visit marked bits in bitmap.
NOTE: You can safely change bits in this bitmap during visiting it since it loads word and then visits marked bits in it.