Struct comet::large_space::LargeObjectSpace [−][src]
pub struct LargeObjectSpace { /* fields omitted */ }Expand description
This space contains objects which are larger than the size limits of other spaces. Each object gets its own malloc’d region of memory. Large objects are never moved by the garbage collector.
Implementations
Sort allocations before consrvative scan.